@@ -24,11 +24,24 @@
 #define _TVG_LOTTIE_BUILDER_H_
 
 #include "tvgCommon.h"
+#include "tvgLottieExpressions.h"
 
 struct LottieComposition;
 
 struct LottieBuilder
 {
+    LottieExpressions* exps = nullptr;
+
+    LottieBuilder()
+    {
+        exps = LottieExpressions::instance();
+    }
+
+    ~LottieBuilder()
+    {
+        LottieExpressions::retrieve(exps);
+    }
+
     bool update(LottieComposition* comp, float progress);
     void build(LottieComposition* comp);
 };
