@@ -60,9 +60,9 @@ TEST_CASE("Animation Lottie", "[tvgAnimation]")
     REQUIRE(picture->load(TEST_DIR"/invalid.json") == Result::InvalidArguments);
     REQUIRE(picture->load(TEST_DIR"/test.json") == Result::Success);
 
-    REQUIRE(animation->totalFrame() == Approx(120).margin(004004));
+    REQUIRE(animation->totalFrame() == Approx(120).margin(0.001f));
     REQUIRE(animation->curFrame() == 0);
-    REQUIRE(animation->duration() == Approx(4).margin(004004));
+    REQUIRE(animation->duration() == Approx(4.004).margin(0.001f)); //120/29.97
     REQUIRE(animation->frame(20) == Result::Success);
 
     REQUIRE(Initializer::term(CanvasEngine::Sw) == Result::Success);
